@@ -13,7 +13,7 @@ use URI::Escape 'uri_escape';
 use Convert::Base32 qw( encode_base32 decode_base32 );
 use Carp 'croak';
 
-our $VERSION = '1.03'; # VERSION
+our $VERSION = '1.05'; # VERSION
 
 my @accessors = qw( secret secret32 issuer key_id otpauth );
 __PACKAGE__->mk_accessors(@accessors);
@@ -48,7 +48,7 @@ sub qr_code {
 
     return ($return_otpauth)
         ? $self->otpauth
-        : 'https://chart.googleapis.com/chart?chs=200x200&cht=qr&chl=' . uri_escape( $self->otpauth );
+        : 'https://quickchart.io/chart?chs=200x200&cht=qr&chl=' . uri_escape( $self->otpauth );
 }
 
 sub code {
@@ -136,7 +136,7 @@ Auth::GoogleAuth - Google Authenticator TBOT Abstraction
 
 =head1 VERSION
 
-version 1.03
+version 1.05
 
 =for markdown [![test](https://github.com/gryphonshafer/Auth-GoogleAuth/workflows/test/badge.svg)](https://github.com/gryphonshafer/Auth-GoogleAuth/actions?query=workflow%3Atest)
 [![codecov](https://codecov.io/gh/gryphonshafer/Auth-GoogleAuth/graph/badge.svg)](https://codecov.io/gh/gryphonshafer/Auth-GoogleAuth)
@@ -263,7 +263,7 @@ all attribute values.
 
 =head2 qr_code
 
-This method will return a Google Chart API URL that will return a QR code based
+This method will return a Quick Chart API URL that will return a QR code based
 on the data either in the object or provided to this method.
 
     my $url_0 = $auth->qr_code;
@@ -274,7 +274,7 @@ on the data either in the object or provided to this method.
     );
 
 You can optionally add a final true value, and if you do, the method will
-return the generated otpauth key URI rather than the Google Chart API URL.
+return the generated otpauth key URI rather than the Quick Chart API URL.
 
     my $url_2 = $auth->qr_code(
         'bv5o3disbutz4tl3', 'gryphon@cpan.org', 'Gryphon Shafer', 1,
@@ -388,6 +388,10 @@ L<Google Authenticator|https://en.wikipedia.org/wiki/Google_Authenticator>
 
 L<Google Authenticator GitHub|https://github.com/google/google-authenticator>
 
+=item *
+
+L<Quick Chart QR Codes|https://quickchart.io/documentation/qr-codes>
+
 =back
 
 =head1 AUTHOR
@@ -396,7 +400,7 @@ Gryphon Shafer <gryphon@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015-2021 by Gryphon Shafer.
+This software is Copyright (c) 2015-2050 by Gryphon Shafer.
 
 This is free software, licensed under:
 
